
# surfingcrypto

![img](https://github.com/giocaizzi/surfingcrypto/blob/gh-pages/docsrc/source/images/logo.png)

![Python](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20-blue)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/giocaizzi/surfingcrypto/ci)
![Codecov](https://img.shields.io/codecov/c/gh/giocaizzi/surfingcrypto)

python package to surf crypto-waves.

- Scrapes *OHLC data* from [www.coinmarketcap.com](www.coinmarketcap.com) and stores it locally.
- Compute *Technical Analysis* indicators and plot complex graphs
- Interact with *Coinbase API* to read transaction data and to compute Portfolio statistics

## Installation

1. First, install direct requirements
   ```shell
   pip install git+https://github.com/giocaizzi/pyfolio.git
   pip install git+https://github.com/mementum/backtrader.git@0fa63ef4a35dc53cc7320813f8b15480c8f85517#egg=backtrader


2. Install with `pip`
   ```shell
   pip install surfingcrypto
   ```

## Documentation

### Read the docs

Documentations can be found [here](https://giocaizzi.github.io/surfingcrypto/)


